# pip install pandas numpy

import pandas as pd
import numpy as np
from datetime import datetime
import random

# Set random seed for reproducibility
np.random.seed(42)

# List of 25 cities around the world
cities = [
    "New York", "Los Angeles", "Chicago", "London", "Paris",
    "Tokyo", "Beijing", "Sydney", "Mumbai", "Cairo",
    "Rio de Janeiro", "Cape Town", "Moscow", "Berlin", "Toronto",
    "Mexico City", "Bangkok", "Stockholm", "Dubai", "Singapore",
    "Istanbul", "Seoul", "Rome", "Amsterdam", "Vancouver"
]

# Months
months = ["January", "February", "March", "April", "May", "June", 
          "July", "August", "September", "October", "November", "December"]

# Create empty list to store data
temperature_data = []

# Generate synthetic temperature data for each city and month
for city in cities:
    # Assign a base temperature profile based on hemisphere and climate
    if city in ["Sydney", "Cape Town", "Rio de Janeiro", "Singapore", "Bangkok"]:
        # Southern hemisphere or tropical
        base_temp = 25  # Higher base temperature
        season_shift = 6  # Shift seasons by 6 months for Southern hemisphere
    elif city in ["Dubai", "Cairo", "Mumbai"]:
        # Hot desert or tropical
        base_temp = 30
        season_shift = 0
    elif city in ["Stockholm", "Moscow", "Toronto", "Vancouver"]:
        # Cold northern
        base_temp = 5
        season_shift = 0
    else:
        # Temperate northern
        base_temp = 15
        season_shift = 0
    
    for i, month in enumerate(months):
        # Calculate seasonal effect (sinusoidal pattern)
        # For Northern hemisphere: peak in July, trough in January
        # For Southern hemisphere: peak in January, trough in July
        season_month_idx = (i + season_shift) % 12
        seasonal_effect = 10 * np.sin((season_month_idx - 3) * (2 * np.pi / 12))
        
        # Average temperature with some randomness
        avg_temp = round(base_temp + seasonal_effect + np.random.normal(0, 2), 1)
        
        # High and low with some random variation
        temp_range = 5 + np.random.uniform(0, 5)  # Random range between 5-10 degrees
        high_temp = round(avg_temp + temp_range / 2, 1)
        low_temp = round(avg_temp - temp_range / 2, 1)
        
        # Add to data list
        temperature_data.append([city, month, avg_temp, high_temp, low_temp])

# Create DataFrame
columns = ["city", "month", "avg_temp", "high_temp", "low_temp"]
df = pd.DataFrame(temperature_data, columns=columns)

# Display first few rows
print(df.head())

# Save to CSV
df.to_csv("city_temperature_data.csv", index=False)

print(f"\nGenerated temperature data for {len(cities)} cities across {len(months)} months.")
print(f"Total records: {len(df)}")
print(f"Data saved to 'city_temperature_data.csv'")

# Show some statistics
print("\nData Statistics:")
print(df.describe())

# Show some example queries
print("\nSample data for New York:")
print(df[df["city"] == "New York"])
